

###############################################################################################
#  AN EXAMPLE TO FIT THE LOGISTIC POSITIVE EXPONENT RESPONSE MODEL: Bayesian Inference                        #
#                                                                                             #
# Data contain 974 respondent to 18 items of Math Test applied in student of  4th grade.       #
# Data are described in Bolfarine, H. and Bazn, J. L. (2010).  Bayesian Estimation of the    #   
# Logistic Positive Exponent IRT model. Journal of Educational Behavioral Statistics, 35,     #
# 693-713.                                                                                    #
###############################################################################################



# install package ltm, psych, foreign
#install.packages(c("ltm","psych","foreign") 

#read data set


library(ltm)
require(foreign)

wd<-"C:\\Users\\Jorge Luis\\Copy\\MinicursTRI\\Exemplos\\Unidimensional"
setwd(wd)

mate=read.spss("Mathpear.sav")
datamat=data.frame(mate)


y=as.matrix(datamat)
colnames(y) <- NULL 

n=nrow(datamat)
I=ncol(datamat)

data<-list(y=y,n=n,I=I)

inits<-function(){list(a=c(rep(1,I)),b=c(rep(1,I)),lambda=c(rep(0.5,I)),theta=c(rep(0.5,n)))}

parameters<-c("a","b","lambda","theta")

n.iter=1400  #Consider 24000
n.burnin=400 #Consider 4000
n.thin=1     #Consider 20

#Usando WinBUGS
#################
#To install WinBUGS see http://www.wcsmalaysia.org/analysis/WinBUGS_install.htm

library(R2WinBUGS)
#bugs directory home
bd="C:/Program Files/WinBUGS14/"

# 2 LPE using type Metrpolis-Hasting algorithm (ARS)
LPE2P<-bugs(data,inits=inits,parameters.to.save=parameters,
model.file="2LPEmodel.txt",working.directory=wd,
n.chains=1,n.iter=n.iter,n.burnin=n.burnin,n.thin=n.thin,bugs.directory=bd)

plot(LPE2P)
print(LPE2P,digits=2)


#convergence analysis 

library("coda")
codaobject <- read.bugs(LPE2P2)
summary(codaobject)
effectiveSize(codaobject)

#parameter a
geweke.diag(codaobject[,c(1:18)])
plot(codaobject[,c(1:21)])
densityplot(codaobject[,c(1:18)]) 
xyplot(codaobject[,c(1:18)])
acfplot(codaobject[,c(1:18)])

#parameter b
geweke.diag(codaobject[,c(19:36)])
plot(codaobject[,c(19:36)])
densityplot(codaobject[,c(19:36)]) 
xyplot(codaobject[,c(19:36)])
acfplot(codaobject[,c(19:36)])

#parameter lambda
geweke.diag(codaobject[,c(37:54)])
plot(codaobject[,c(37:54)])
densityplot(codaobject[,c(37:54)]) 
xyplot(codaobject[,c(37:54)])
acfplot(codaobject[,c(37:54)]) 



#Note. WinBugs and R2WinBUGS is more quickly that OpenBUGS with R2OpenBUGS or brugs


